pub enum ColorMode {
    Accurate,
    Web,
}
The color mode of an [Atlas].

Variants



Accurate

Accurate color management.

This mode will use a proper sRGB texture for colored glyphs. This will produce physically accurate color blending when rendering.



Web

Web color management.

This mode reproduces the color management strategy used in the Web and implemented by browsers.

This entails storing glyphs colored using the sRGB color space in a linear RGB texture. Blending will not be physically accurate, but will produce the same results as most UI toolkits.

This mode should be used to render to a linear RGB texture containing sRGB colors.